/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.api.stream.sql

import org.apache.flink.api.scala._
import org.apache.flink.table.api.scala._
import org.apache.flink.table.util.{StreamTableTestUtil, TableTestBase}
import org.junit.Test

class TableRefConversionTest extends TableTestBase {

  val util: StreamTableTestUtil = streamTestUtil()
  util.addTable[(Int, Long, String)]("MyTable1", 'a, 'b, 'c)
  util.addTable[(Int, Long, String)]("MyTable2", 'c, 'd, 'e)

  @Test
  def testTableRefConversion1(): Unit = {
    val view = util.tableEnv.sqlQuery(
      "SELECT * FROM MyTable1 WHERE b IN (SELECT d FROM MyTable2 WHERE c = e)")
    util.tableEnv.registerTable("MyView", view)
    util.verifyPlan("SELECT a, c FROM MyView WHERE c > 10")
  }

  @Test
  def testTableRefConversion2(): Unit = {
    val view = util.tableEnv.sqlQuery(
      "SELECT * FROM MyTable1 WHERE b = (SELECT MAX(d) FROM MyTable2 WHERE c = e)")
    util.tableEnv.registerTable("MyView", view)
    util.verifyPlan("SELECT a, c FROM MyView WHERE c > 10")
  }

}
