/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.flink.table.plan.batch.sql

import org.apache.flink.api.scala._
import org.apache.flink.table.api.TableException
import org.apache.flink.table.api.scala._
import org.apache.flink.table.util.TableTestBase
import org.junit.{Before, Test}

class SortLimitTest extends TableTestBase {

  private val util = batchTestUtil()

  @Before
  def setup(): Unit = {
    util.addTable[(Int, Long, Int)]("MyTable", 'a, 'b, 'c)
  }

  @Test
  def testSortLimit(): Unit = {
    val sqlQuery = "SELECT a, c FROM MyTable ORDER BY a DESC LIMIT 10"
    util.verifyPlan(sqlQuery)
  }

  @Test
  def testSortLimitWithOffset(): Unit = {
    val sqlQuery = "SELECT a, c FROM MyTable ORDER BY a DESC LIMIT 10 OFFSET 2"
    util.verifyPlan(sqlQuery)
  }

  @Test
  def testSortFetch(): Unit = {
    val sqlQuery = "SELECT a, c FROM MyTable ORDER BY a DESC FETCH FIRST 8 ROWS ONLY"
    util.verifyPlan(sqlQuery)
  }

  @Test
  def testSortFetchWithOffset(): Unit = {
    val sqlQuery = "SELECT a, c FROM MyTable ORDER BY a DESC OFFSET 2 ROWS FETCH NEXT 8 ROWS ONLY"
    util.verifyPlan(sqlQuery)
  }

  @Test(expected = classOf[TableException])
  def testSortWithOffset(): Unit = {
    val sqlQuery = "SELECT a, c FROM MyTable ORDER BY a DESC OFFSET 2 ROWS"
    util.printSql(sqlQuery)
  }
}
